#
#WINDOW BUILDER PROJECT MASTER SRC
import mwt

mwt.WSGFdeviceInitialize()
app = mwt.WSGIappDev()
mwt.WSGFwsInitialize()

mwt.WSGFsetDefaultEncoding(20);
#--- OBJECT execute auto initialize ---
import newwin000
import resizeep
import exitep
import numbtnep
import acbtnep
import dotbtnep
import cbtnep
import pmbtnep
import opbtnep
app.handleEvents()

